##  Approving Fact Sheet Quality
When the quality seal feature is enabled for a fact sheet type, a quality seal icon appears at the top of each fact sheet of that type. Responsible or accountable subscribers can click on the icon, and from the drop-down menu, choose and change the quality seal state. You can approve the quality seal by selecting Approve Fact Sheet.
![Approving or Changing Quality Seal State](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749e3587a441014bd38f0cd5245c6e6_LowRes.png)
Approving or Changing Quality Seal State
Besides the automatic breaking of the quality seal when the fact sheet attributes are changed, you can manually break it by selecting Break Quality Seal. It may be necessary in certain situations to indicate that the information on the fact sheet needs to be reviewed or updated. For example, if errors have been identified, breaking the quality seal can prompt a review process to ensure accuracy and completeness
![Manually Breaking Quality Seal](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2751de887a4410148aedc32566ad8e05_LowRes.png)
Manually Breaking Quality Seal
Users who do not have permission to change the quality seal see just the quality seal of the fact sheet.
